@@ -87,7 +87,7 @@ class KlaviyoAPI:
         self.Campaigns.get_campaign_message=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_message))
         self.Campaigns.get_campaign_recipient_estimation=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_recipient_estimation))
         self.Campaigns.get_campaign_recipient_estimation_job=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_recipient_estimation_job))
-        self.Campaigns.get_campaign_relationships=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_relationships))
+        self.Campaigns.get_campaign_relationships_tags=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_relationships_tags))
         self.Campaigns.get_campaign_send_job=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_send_job))
         self.Campaigns.get_campaign_tags=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaign_tags))
         self.Campaigns.get_campaigns=self._page_cursor_update(self.retry_logic(self.Campaigns.get_campaigns))
@@ -101,22 +101,22 @@ class KlaviyoAPI:
         
         ## Applying tenacity retry decorator to each endpoint in Catalogs
         self.Catalogs.create_catalog_category=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_category))
-        self.Catalogs.create_catalog_category_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_category_relationships))
+        self.Catalogs.create_catalog_category_relationships_items=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_category_relationships_items))
         self.Catalogs.create_catalog_item=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_item))
-        self.Catalogs.create_catalog_item_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_item_relationships))
+        self.Catalogs.create_catalog_item_relationships_categories=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_item_relationships_categories))
         self.Catalogs.create_catalog_variant=self._page_cursor_update(self.retry_logic(self.Catalogs.create_catalog_variant))
         self.Catalogs.delete_catalog_category=self._page_cursor_update(self.retry_logic(self.Catalogs.delete_catalog_category))
-        self.Catalogs.delete_catalog_category_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.delete_catalog_category_relationships))
+        self.Catalogs.delete_catalog_category_relationships_items=self._page_cursor_update(self.retry_logic(self.Catalogs.delete_catalog_category_relationships_items))
         self.Catalogs.delete_catalog_item=self._page_cursor_update(self.retry_logic(self.Catalogs.delete_catalog_item))
-        self.Catalogs.delete_catalog_item_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.delete_catalog_item_relationships))
+        self.Catalogs.delete_catalog_item_relationships_categories=self._page_cursor_update(self.retry_logic(self.Catalogs.delete_catalog_item_relationships_categories))
         self.Catalogs.delete_catalog_variant=self._page_cursor_update(self.retry_logic(self.Catalogs.delete_catalog_variant))
         self.Catalogs.get_catalog_categories=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_categories))
         self.Catalogs.get_catalog_category=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_category))
         self.Catalogs.get_catalog_category_items=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_category_items))
-        self.Catalogs.get_catalog_category_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_category_relationships))
+        self.Catalogs.get_catalog_category_relationships_items=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_category_relationships_items))
         self.Catalogs.get_catalog_item=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_item))
         self.Catalogs.get_catalog_item_categories=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_item_categories))
-        self.Catalogs.get_catalog_item_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_item_relationships))
+        self.Catalogs.get_catalog_item_relationships_categories=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_item_relationships_categories))
         self.Catalogs.get_catalog_item_variants=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_item_variants))
         self.Catalogs.get_catalog_items=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_items))
         self.Catalogs.get_catalog_variant=self._page_cursor_update(self.retry_logic(self.Catalogs.get_catalog_variant))
@@ -149,9 +149,9 @@ class KlaviyoAPI:
         self.Catalogs.spawn_update_items_job=self._page_cursor_update(self.retry_logic(self.Catalogs.spawn_update_items_job))
         self.Catalogs.spawn_update_variants_job=self._page_cursor_update(self.retry_logic(self.Catalogs.spawn_update_variants_job))
         self.Catalogs.update_catalog_category=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_category))
-        self.Catalogs.update_catalog_category_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_category_relationships))
+        self.Catalogs.update_catalog_category_relationships_items=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_category_relationships_items))
         self.Catalogs.update_catalog_item=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_item))
-        self.Catalogs.update_catalog_item_relationships=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_item_relationships))
+        self.Catalogs.update_catalog_item_relationships_categories=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_item_relationships_categories))
         self.Catalogs.update_catalog_variant=self._page_cursor_update(self.retry_logic(self.Catalogs.update_catalog_variant))
         
         
@@ -179,7 +179,8 @@ class KlaviyoAPI:
         self.Events.get_event=self._page_cursor_update(self.retry_logic(self.Events.get_event))
         self.Events.get_event_metrics=self._page_cursor_update(self.retry_logic(self.Events.get_event_metrics))
         self.Events.get_event_profiles=self._page_cursor_update(self.retry_logic(self.Events.get_event_profiles))
-        self.Events.get_event_relationships=self._page_cursor_update(self.retry_logic(self.Events.get_event_relationships))
+        self.Events.get_event_relationships_metrics=self._page_cursor_update(self.retry_logic(self.Events.get_event_relationships_metrics))
+        self.Events.get_event_relationships_profiles=self._page_cursor_update(self.retry_logic(self.Events.get_event_relationships_profiles))
         self.Events.get_events=self._page_cursor_update(self.retry_logic(self.Events.get_events))
         
         
@@ -191,12 +192,14 @@ class KlaviyoAPI:
         self.Flows.get_flow_action=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_action))
         self.Flows.get_flow_action_flow=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_action_flow))
         self.Flows.get_flow_action_messages=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_action_messages))
-        self.Flows.get_flow_action_relationships=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_action_relationships))
+        self.Flows.get_flow_action_relationships_flow=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_action_relationships_flow))
+        self.Flows.get_flow_action_relationships_messages=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_action_relationships_messages))
         self.Flows.get_flow_flow_actions=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_flow_actions))
         self.Flows.get_flow_message=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_message))
         self.Flows.get_flow_message_action=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_message_action))
-        self.Flows.get_flow_message_relationships=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_message_relationships))
-        self.Flows.get_flow_relationships=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_relationships))
+        self.Flows.get_flow_message_relationships_action=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_message_relationships_action))
+        self.Flows.get_flow_relationships_flow_actions=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_relationships_flow_actions))
+        self.Flows.get_flow_relationships_tags=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_relationships_tags))
         self.Flows.get_flow_tags=self._page_cursor_update(self.retry_logic(self.Flows.get_flow_tags))
         self.Flows.get_flows=self._page_cursor_update(self.retry_logic(self.Flows.get_flows))
         self.Flows.update_flow=self._page_cursor_update(self.retry_logic(self.Flows.update_flow))
@@ -212,7 +215,8 @@ class KlaviyoAPI:
         self.Lists.delete_list_relationships=self._page_cursor_update(self.retry_logic(self.Lists.delete_list_relationships))
         self.Lists.get_list=self._page_cursor_update(self.retry_logic(self.Lists.get_list))
         self.Lists.get_list_profiles=self._page_cursor_update(self.retry_logic(self.Lists.get_list_profiles))
-        self.Lists.get_list_relationships=self._page_cursor_update(self.retry_logic(self.Lists.get_list_relationships))
+        self.Lists.get_list_relationships_profiles=self._page_cursor_update(self.retry_logic(self.Lists.get_list_relationships_profiles))
+        self.Lists.get_list_relationships_tags=self._page_cursor_update(self.retry_logic(self.Lists.get_list_relationships_tags))
         self.Lists.get_list_tags=self._page_cursor_update(self.retry_logic(self.Lists.get_list_tags))
         self.Lists.get_lists=self._page_cursor_update(self.retry_logic(self.Lists.get_lists))
         self.Lists.update_list=self._page_cursor_update(self.retry_logic(self.Lists.update_list))
@@ -234,7 +238,8 @@ class KlaviyoAPI:
         self.Profiles.create_profile=self._page_cursor_update(self.retry_logic(self.Profiles.create_profile))
         self.Profiles.get_profile=self._page_cursor_update(self.retry_logic(self.Profiles.get_profile))
         self.Profiles.get_profile_lists=self._page_cursor_update(self.retry_logic(self.Profiles.get_profile_lists))
-        self.Profiles.get_profile_relationships=self._page_cursor_update(self.retry_logic(self.Profiles.get_profile_relationships))
+        self.Profiles.get_profile_relationships_lists=self._page_cursor_update(self.retry_logic(self.Profiles.get_profile_relationships_lists))
+        self.Profiles.get_profile_relationships_segments=self._page_cursor_update(self.retry_logic(self.Profiles.get_profile_relationships_segments))
         self.Profiles.get_profile_segments=self._page_cursor_update(self.retry_logic(self.Profiles.get_profile_segments))
         self.Profiles.get_profiles=self._page_cursor_update(self.retry_logic(self.Profiles.get_profiles))
         self.Profiles.subscribe_profiles=self._page_cursor_update(self.retry_logic(self.Profiles.subscribe_profiles))
@@ -250,7 +255,8 @@ class KlaviyoAPI:
         ## Applying tenacity retry decorator to each endpoint in Segments
         self.Segments.get_segment=self._page_cursor_update(self.retry_logic(self.Segments.get_segment))
         self.Segments.get_segment_profiles=self._page_cursor_update(self.retry_logic(self.Segments.get_segment_profiles))
-        self.Segments.get_segment_relationships=self._page_cursor_update(self.retry_logic(self.Segments.get_segment_relationships))
+        self.Segments.get_segment_relationships_profiles=self._page_cursor_update(self.retry_logic(self.Segments.get_segment_relationships_profiles))
+        self.Segments.get_segment_relationships_tags=self._page_cursor_update(self.retry_logic(self.Segments.get_segment_relationships_tags))
         self.Segments.get_segment_tags=self._page_cursor_update(self.retry_logic(self.Segments.get_segment_tags))
         self.Segments.get_segments=self._page_cursor_update(self.retry_logic(self.Segments.get_segments))
         self.Segments.update_segment=self._page_cursor_update(self.retry_logic(self.Segments.update_segment))
@@ -262,16 +268,26 @@ class KlaviyoAPI:
         ## Applying tenacity retry decorator to each endpoint in Tags
         self.Tags.create_tag=self._page_cursor_update(self.retry_logic(self.Tags.create_tag))
         self.Tags.create_tag_group=self._page_cursor_update(self.retry_logic(self.Tags.create_tag_group))
-        self.Tags.create_tag_relationships=self._page_cursor_update(self.retry_logic(self.Tags.create_tag_relationships))
+        self.Tags.create_tag_relationships_campaigns=self._page_cursor_update(self.retry_logic(self.Tags.create_tag_relationships_campaigns))
+        self.Tags.create_tag_relationships_flows=self._page_cursor_update(self.retry_logic(self.Tags.create_tag_relationships_flows))
+        self.Tags.create_tag_relationships_lists=self._page_cursor_update(self.retry_logic(self.Tags.create_tag_relationships_lists))
+        self.Tags.create_tag_relationships_segments=self._page_cursor_update(self.retry_logic(self.Tags.create_tag_relationships_segments))
         self.Tags.delete_tag=self._page_cursor_update(self.retry_logic(self.Tags.delete_tag))
         self.Tags.delete_tag_group=self._page_cursor_update(self.retry_logic(self.Tags.delete_tag_group))
-        self.Tags.delete_tag_relationships=self._page_cursor_update(self.retry_logic(self.Tags.delete_tag_relationships))
+        self.Tags.delete_tag_relationships_campaigns=self._page_cursor_update(self.retry_logic(self.Tags.delete_tag_relationships_campaigns))
+        self.Tags.delete_tag_relationships_flows=self._page_cursor_update(self.retry_logic(self.Tags.delete_tag_relationships_flows))
+        self.Tags.delete_tag_relationships_lists=self._page_cursor_update(self.retry_logic(self.Tags.delete_tag_relationships_lists))
+        self.Tags.delete_tag_relationships_segments=self._page_cursor_update(self.retry_logic(self.Tags.delete_tag_relationships_segments))
         self.Tags.get_tag=self._page_cursor_update(self.retry_logic(self.Tags.get_tag))
         self.Tags.get_tag_group=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_group))
-        self.Tags.get_tag_group_relationships=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_group_relationships))
+        self.Tags.get_tag_group_relationships_tags=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_group_relationships_tags))
         self.Tags.get_tag_group_tags=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_group_tags))
         self.Tags.get_tag_groups=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_groups))
-        self.Tags.get_tag_relationships=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_relationships))
+        self.Tags.get_tag_relationships_campaigns=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_relationships_campaigns))
+        self.Tags.get_tag_relationships_flows=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_relationships_flows))
+        self.Tags.get_tag_relationships_lists=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_relationships_lists))
+        self.Tags.get_tag_relationships_segments=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_relationships_segments))
+        self.Tags.get_tag_relationships_tag_group=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_relationships_tag_group))
         self.Tags.get_tag_tag_group=self._page_cursor_update(self.retry_logic(self.Tags.get_tag_tag_group))
         self.Tags.get_tags=self._page_cursor_update(self.retry_logic(self.Tags.get_tags))
         self.Tags.update_tag=self._page_cursor_update(self.retry_logic(self.Tags.update_tag))
